/*
  Java gfx-test framework

   Copyright (C) 2014  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.geom.Area;



import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;



/**
 * This test checks the process of creating and rendering new geometric shapes
 * by performing boolean operations on existing ones. This process is often
 * called Constructive area geometry (CAG). All CAG operations - union,
 * intersection, subtraction and XOR - is processed on two overlapping round rectangles.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.AREA)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class CAGOperationsOnTwoOverlappingRoundRectangles extends GfxTest
{

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two round rectangles using union operator. The shape is
     * rendered using stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using subtract operator. The shape is
     * rendered using stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using inverse subtract operator. The
     * shape is rendered using stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using intersect operator. The
     * shape is rendered using stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using XOR operator. The
     * shape is rendered using stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using subtract operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using inverse subtract operator. The
     * shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using intersect operator. The
     * shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using XOR operator. The
     * shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using union operator. The shape is
     * rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using subtract operator. The shape is
     * rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using inverse subtract operator. The
     * shape is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using intersect operator. The
     * shape is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using XOR operator. The
     * shape is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using zero wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionZeroStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeZeroThick(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is
     * rendered using zero stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractZeroStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeZeroThick(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape
     * is rendered using zero stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractZeroStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeZeroThick(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using intersect operator. The shape is
     * rendered using zero stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectZeroStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeZeroThick(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using XOR operator. The shape is rendered
     * using zero stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorZeroStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeZeroThick(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using union operator. The shape is
     * rendered using color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using subtract operator. The shape is
     * rendered using color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using inverse subtract operator. The
     * shape is rendered using color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using intersect operator. The
     * shape is rendered using color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using XOR operator. The
     * shape is rendered using color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using union operator. The shape is
     * rendered using horizontal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using subtract operator. The shape is
     * rendered using horizontal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using inverse subtract operator. The
     * shape is rendered using horizontal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using intersect operator. The
     * shape is rendered using horizontal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using XOR operator. The
     * shape is rendered using horizontal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using union operator. The shape is
     * rendered using vertical gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using subtract operator. The shape is
     * rendered using vertical gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using inverse subtract operator. The
     * shape is rendered using vertical gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using intersect operator. The
     * shape is rendered using vertical gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using XOR operator. The
     * shape is rendered using vertical gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using union operator. The shape is
     * rendered using diagonal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using subtract operator. The shape is
     * rendered using diagonal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using inverse subtract operator. The
     * shape is rendered using diagonal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using intersect operator. The
     * shape is rendered using diagonal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using XOR operator. The
     * shape is rendered using diagonal gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using union operator. The shape is
     * rendered using radial gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using subtract operator. The shape is
     * rendered using radial gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using inverse subtract operator. The
     * shape is rendered using radial gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using intersect operator. The
     * shape is rendered using radial gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two rectangles using XOR operator. The
     * shape is rendered using radial gradient color paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingCheckerTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingCheckerTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingCheckerTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingCheckerTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingCheckerTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingDiagonalCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalCheckerTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingDiagonalCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalCheckerTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingDiagonalCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalCheckerTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingDiagonalCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalCheckerTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingDiagonalCheckerTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalCheckerTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingGridTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingGridTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingGridTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingGridTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingGridTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingDiagonalGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalGridTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingDiagonalGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalGridTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingDiagonalGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalGridTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingDiagonalGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalGridTexture(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingDiagonalGridTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalGridTexture(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingHorizontalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalStripesTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingHorizontalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalStripesTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingHorizontalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalStripesTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingHorizontalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalStripesTexture(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingHorizontalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalStripesTexture(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingVerticalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalStripesTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingVerticalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalStripesTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingVerticalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalStripesTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingVerticalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalStripesTexture(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingVerticalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalStripesTexture(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingHorizontalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalColorStripesTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingHorizontalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalColorStripesTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingHorizontalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalColorStripesTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingHorizontalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalColorStripesTexture(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingHorizontalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingHorizontalColorStripesTexture(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingVerticalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalColorStripesTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingVerticalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalColorStripesTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingVerticalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalColorStripesTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingVerticalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalColorStripesTexture(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingVerticalColorStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingVerticalColorStripesTexture(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingDiagonalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalStripesTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingDiagonalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalStripesTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingDiagonalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalStripesTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingDiagonalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalStripesTexture(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingDiagonalStripesTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingDiagonalStripesTexture(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingColorDotsTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingColorDotsTexture(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingColorDotsTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingColorDotsTexture(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingColorDotsTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingColorDotsTexture(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingColorDotsTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingColorDotsTexture(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingColorDotsTexture(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingColorDotsTexture(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingRGBTexture1(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture1(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingRGBTexture1(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture1(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingRGBTexture1(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture1(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingRGBTexture1(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture1(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingRGBTexture1(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture1(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingRGBTexture2(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture2(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingRGBTexture2(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture2(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingRGBTexture2(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture2(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingRGBTexture2(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture2(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingRGBTexture2(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture2(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingRGBTexture3(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture3(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingRGBTexture3(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture3(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingRGBTexture3(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture3(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingRGBTexture3(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture3(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingRGBTexture3(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture3(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingRGBTexture4(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture4(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingRGBTexture4(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture4(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingRGBTexture4(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture4(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingRGBTexture4(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture4(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingRGBTexture4(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture4(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingRGBTexture5(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture5(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingRGBTexture5(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture5(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingRGBTexture5(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture5(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingRGBTexture5(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture5(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingRGBTexture5(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture5(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using union operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testUnionTextureFillUsingRGBTexture6(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture6(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingUnionOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
         * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSubtractTextureFillUsingRGBTexture6(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture6(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using inverse subtract operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testInverseSubtractTextureFillUsingRGBTexture6(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture6(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Intersect operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testIntersectTextureFillUsingRGBTexture6(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture6(image, graphics2d);
        // create area using Intersect operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingIntersectOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from two overlapping round rectangles using Xor operator. The shape is rendered
     * using texture paint (fill).
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testXorTextureFillUsingRGBTexture6(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture6(image, graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromTwoOverlappingRoundRectanglesUsingXorOperator(image);
        // draw the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new CAGOperationsOnTwoOverlappingRoundRectangles().runTestSuite(args);
    }

}
